@@ -7,8 +7,10 @@
 
 int fd_sync (int fd)
 {
+  int e = errno ;
   int r ;
   do r = fsync(fd) ;
   while (r == -1 && errno == EINTR) ;
+  if (r >= 0) errno = e ;
   return r ;
 }
