@@ -3,7 +3,7 @@
 #include <skalibs/stralloc.h>
 #include <skalibs/genalloc.h>
 
-void genalloc_deepfree_size (genalloc *g, freefunc_t_ref f, size_t size)
+void genalloc_deepfree_size (genalloc *g, free_func_ref f, size_t size)
 {
   size_t len = g->len / size ;
   size_t i = 0 ;
