@@ -1,6 +1,7 @@
 /* ISC license. */
 
 #include <skalibs/nonposix.h>
+
 #include <string.h>
 #include <errno.h>
 #include <sys/socket.h>
@@ -11,14 +12,16 @@
 
 ssize_t ipc_recv (int fd, char *s, size_t len, char *path)
 {
+  int e = errno ;
   struct sockaddr_un sa = { .sun_family = AF_UNIX } ;
   socklen_t total = sizeof sa ;
   char tmp[len] ;
   ssize_t r ;
   do r = recvfrom(fd, tmp, len, 0, (struct sockaddr *)&sa, &total) ;
-  while ((r == -1) && (errno == EINTR)) ;
-  if (r < 0) return r ;
+  while (r == -1 && errno == EINTR) ;
+  if (r == -1) return r ;
   if (sa.sun_family != AF_UNIX) return (errno = EPROTO, -1) ;
+  errno = e ;
   if (path)
   {
     if (total == sizeof(sa_family_t)) path[0] = 0 ;
