@@ -2,12 +2,14 @@
 
 /* MT-unsafe */
 
+#include <errno.h>
 #include <signal.h>
 
 #include <skalibs/sig.h>
 
 void sig_restoreto (sigset_t const *set, unsigned int n)
 {
+  int e = errno ;
   unsigned int i = 1 ;
   for (; i < n ; i++)
   {
@@ -15,4 +17,5 @@ void sig_restoreto (sigset_t const *set, unsigned int n)
     if (h < 0) continue ;
     if (h) sig_restore(i) ;
   }
+  errno = e ;
 }
