@@ -15,6 +15,7 @@
 
 int socket_connect6 (int s, char const *ip6, uint16_t port)
 {
+  int e = errno ;
   struct sockaddr_in6 sa ;
   int r ;
   memset(&sa, 0, sizeof sa) ;
@@ -22,8 +23,9 @@ int socket_connect6 (int s, char const *ip6, uint16_t port)
   sa.sin6_port = uint16_big(port) ;
   memcpy(sa.sin6_addr.s6_addr, ip6, 16) ;
   do r = connect(s, (struct sockaddr *)&sa, sizeof sa) ;
-  while ((r == -1) && (errno == EINTR)) ;
-  if ((r == -1) && (errno == EALREADY)) errno = EINPROGRESS ;
+  while (r == -1 && errno == EINTR) ;
+  if (r == -1 && errno == EALREADY) errno = EINPROGRESS ;
+  if (r >= 0) errno = e ;
   return r ;
 }
 
