@@ -15,12 +15,14 @@
 
 ssize_t socket_recv6 (int s, char *buf, size_t len, char *ip6, uint16_t *port)
 {
+  int e = errno ;
   struct sockaddr_in6 sa ;
   socklen_t dummy = sizeof sa ;
   ssize_t r ;
   do r = recvfrom(s, buf, len, 0, (struct sockaddr *)&sa, &dummy) ;
-  while ((r == -1) && (errno == EINTR)) ;
+  while (r == -1 && errno == EINTR) ;
   if (r == -1) return -1 ;
+  errno = e ;
   memcpy(ip6, sa.sin6_addr.s6_addr, 16) ;
   *port = uint16_big(sa.sin6_port) ;
   return r ;
