@@ -15,6 +15,7 @@
 
 ssize_t socket_send6 (int s, char const *buf, size_t len, char const *ip6, uint16_t port)
 {
+  int e = errno ;
   ssize_t r ;
   struct sockaddr_in6 sa ;
   memset(&sa, 0, sizeof sa) ;
@@ -22,7 +23,8 @@ ssize_t socket_send6 (int s, char const *buf, size_t len, char const *ip6, uint1
   sa.sin6_port = uint16_big(port) ;
   memcpy(sa.sin6_addr.s6_addr, ip6, 16) ;
   do r = sendto(s, buf, len, 0, (struct sockaddr *)&sa, sizeof sa) ;
-  while ((r == -1) && (errno == EINTR)) ;
+  while (r == -1 && errno == EINTR) ;
+  if (r >= 0) errno = e ;
   return r ;
 }
 
