@@ -10,6 +10,6 @@
 
 int socket_tcpnodelay (int s)
 {
-  static int const opt = TCP_NODELAY ;
-  return setsockopt(s, IPPROTO_TCP, 1, &opt, sizeof(int)) ;
+  static int const val = 1 ;
+  return setsockopt(s, IPPROTO_TCP, TCP_NODELAY, &val, sizeof(int)) ;
 }
